#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fuzzy
version:              0.1.0.0
visibility:           public
id:                   fuzzy-0.1.0.0-G8Hez7wf78XFxniOIXLqjb
key:                  fuzzy-0.1.0.0-G8Hez7wf78XFxniOIXLqjb
license:              MIT
maintainer:           joomy@cattheory.com
author:               Joomy Korkut
homepage:             http://github.com/joom/fuzzy
synopsis:             Filters a list based on a fuzzy string search.
category:             Text
abi:                  819aa946418c413e401c696b9facc760
exposed:              True
exposed-modules:      Text.Fuzzy
import-dirs:          /usr/lib/ghc-8.10.5/site-local/fuzzy-0.1.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/fuzzy-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/fuzzy-0.1.0.0
hs-libraries:         HSfuzzy-0.1.0.0-G8Hez7wf78XFxniOIXLqjb
depends:
    base-4.14.2.0 monoid-subclasses-1.1-LYfQSie6ZTZ5E7uELcpBEz

haddock-interfaces:   /usr/share/doc/haskell-fuzzy/html/fuzzy.haddock
haddock-html:         /usr/share/doc/haskell-fuzzy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

